@@ -57,6 +57,7 @@ PARAMFILE_DISABLED = set([
     'custom.deploy.template-file',
 
     'cloudformation.update-stack.stack-policy-during-update-url',
+    'cloudformation.register-type.schema-handler-package',
     # We will want to change the event name to ``s3`` as opposed to
     # custom in the near future along with ``s3`` to ``s3api``.
     'custom.cp.website-redirect',
@@ -76,6 +77,8 @@ PARAMFILE_DISABLED = set([
     'comprehend.detect-sentiment.text',
     'comprehend.batch-detect-sentiment.text-list',
 
+    'emr.create-studio.idp-auth-url',
+
     'iam.create-open-id-connect-provider.url',
 
     'machine-learning.predict.predict-endpoint',
@@ -107,6 +110,12 @@ PARAMFILE_DISABLED = set([
     'service-catalog.create-product.support-url',
     'service-catalog.update-product.support-url',
 
+    'ses.create-custom-verification-email-template.failure-redirection-url',
+    'ses.create-custom-verification-email-template.success-redirection-url',
+    'ses.put-account-details.website-url',
+    'ses.update-custom-verification-email-template.failure-redirection-url',
+    'ses.update-custom-verification-email-template.success-redirection-url',
+
     'sqs.add-permission.queue-url',
     'sqs.change-message-visibility.queue-url',
     'sqs.change-message-visibility-batch.queue-url',
